#<ImportSpecificModules>
import ShareYourSystem as SYS
#</ImportSpecificModules>


#print(SYS.DistanceClass().insert('Parameter').hdfview().HdformatedConsoleStr)
#print(SYS.DistanceClass().insert('Result').hdfview().HdformatedConsoleStr)
#print(SYS.Distance.attest_insert())
#print(SYS.Distance.attest_retrieve())
#print(SYS.Distance.attest_find())
#print(SYS.Distance.attest_recover())
#print(SYS.Distance.attest_scan())


